/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.ui.preference;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.ui.IWorkbenchPropertyPage;
import org.eclipse.ui.dialogs.PropertyPage;

/**
 * プロパティー・ページ基底クラス。
 *
 * <UL>
 * <LI>プレファランスとプロジェクト設定を共通化するためのプロパティー・ページ基底クラスです。
 * </UL>
 *
 * @author KASHIHARA Shinji
 */
public class AbstractProjectPropertyPage extends PropertyPage implements IWorkbenchPropertyPage {

	/** 設定ページ */
	protected AbstractPreferencePage preferencePage;

	/** プロジェクト固有設定かどうかを保管するキー */
	protected String useProjectSettingsStoreKey;

	/** プロジェクト固有設定の使用チェックボックス */
	private Button useProjectSettingsCheck;

	@Override
	protected IPreferenceStore doGetPreferenceStore() {
		return BentenProjectProperty.getStore((IProject) getElement());
	}

	@Override
	protected Control createContents(final Composite parent) {
		final IPreferenceStore store = getPreferenceStore();

		useProjectSettingsCheck = new Button(parent, SWT.CHECK);
		useProjectSettingsCheck.setText("プロジェクト固有の設定を可能にする");
		useProjectSettingsCheck.setSelection(store.getBoolean(useProjectSettingsStoreKey));

		final Label label = new Label(parent, SWT.SEPARATOR | SWT.HORIZONTAL);
		label.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_FILL));

		preferencePage.setPreferenceStore(useProjectSettingsCheck.getSelection() ? store : null);
		final Control contents = preferencePage.createContents(parent);
		preferencePage.setEnabled(useProjectSettingsCheck.getSelection());

		useProjectSettingsCheck.addSelectionListener(new SelectionAdapter() {
			@Override
			public void widgetSelected(final SelectionEvent e) {
				preferencePage.setEnabled(useProjectSettingsCheck.getSelection());
			}
		});
		return contents;
	}

	@Override
	public boolean performOk() {
		final IPreferenceStore store = getPreferenceStore();
		store.setValue(useProjectSettingsStoreKey, useProjectSettingsCheck.getSelection());
		if (useProjectSettingsCheck.getSelection()) {
			preferencePage.setPreferenceStore(store);
			return preferencePage.performOk();
		}
		return true;
	}

	@Override
	protected void performDefaults() {
		useProjectSettingsCheck.setSelection(false);
		preferencePage.performDefaults();
	}
}
